@@ -40,7 +40,7 @@ class Exceptions:
 
 class SageMakerRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html)
     """
 
@@ -56,21 +56,21 @@ class SageMakerRuntimeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#can_paginate)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#generate_presigned_url)
         """
 
@@ -79,20 +79,20 @@ class SageMakerRuntimeClient(BaseClient):
         *,
         EndpointName: str,
         Body: Union[bytes, IO[bytes], StreamingBody],
-        ContentType: str = None,
-        Accept: str = None,
-        CustomAttributes: str = None,
-        TargetModel: str = None,
-        TargetVariant: str = None,
-        TargetContainerHostname: str = None,
-        InferenceId: str = None
+        ContentType: str = ...,
+        Accept: str = ...,
+        CustomAttributes: str = ...,
+        TargetModel: str = ...,
+        TargetVariant: str = ...,
+        TargetContainerHostname: str = ...,
+        InferenceId: str = ...
     ) -> InvokeEndpointOutputTypeDef:
         """
         After you deploy a model into production using Amazon SageMaker hosting
         services, your client applications use this API to get inferences from the model
         hosted at the specified endpoint.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#invoke_endpoint)
         """
 
@@ -101,15 +101,15 @@ class SageMakerRuntimeClient(BaseClient):
         *,
         EndpointName: str,
         InputLocation: str,
-        ContentType: str = None,
-        Accept: str = None,
-        CustomAttributes: str = None,
-        InferenceId: str = None,
-        RequestTTLSeconds: int = None
+        ContentType: str = ...,
+        Accept: str = ...,
+        CustomAttributes: str = ...,
+        InferenceId: str = ...,
+        RequestTTLSeconds: int = ...
     ) -> InvokeEndpointAsyncOutputTypeDef:
         """
         .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.49/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint_async)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.58/reference/services/sagemaker-runtime.html#SageMakerRuntime.Client.invoke_endpoint_async)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_runtime/client.html#invoke_endpoint_async)
         """
